Данный модуль используется для работы с системой мониторига 2.0 (monitoring2), личным кабинетом 1-ofd.ru (prodRf) и GrayLog (grayLog).
---
###***monitoring2***
`Модуль предназанчен для работы с мониторингом 2.0`
**Инициализация** monitoring2(login, password, url = 'http://taxplayer.ensyco.local', crpt = False), где crpt - зашифрованый пароль
+  **login** - Авторизация. Запускается автоматически при инициализации объекта, но можно запустить принудительно.
+  **seek_by_inn(inn, rows = 50, page = 1)** - Поиск организации по ИНН, ОГРН
+  **seek_by_orgId(orgId)** - Поиск организации по id
+  **seek_by_contract(contract)** - Поиск организации по номеру договора
+  **seek_kkm(kkm)** - Поиск ККТ по id, РНМ, ФН
+  **seek_transaction(transaction)** - Поиск транзакции по id
+  **create_report(form)** - Планирование отчёта
+  **get_report_info(uuid)** - Информация о ранее запланированном отчёте
+  **download_report(uuid, file)** - Скачивание ранее запланированного отчёта. Отчёт будет созан с именем file
+  **cancel_report(uuid)** - Отмена ранее запланированного отчёта
+  **ctrl(org_id ,ctrl_login)** - Привязываание учётной записи ctrl к ЛК
+  **user_by_mail(mail)** - Поиск пользователя по почте
+  **user_by_id(id)** - Поиск пользователя по id
---
###***prodRf***
`Модуль предназначен для работы с ЛК прод РФ`
**Инициализация** prodRf(login , password , URL = 'https://api.1-ofd.ru', crpt = False), где crpt - зашифрованый пароль
+  **login** - Авторизация. Запускается автоматически при инициализации объекта, но можно запустить принудительно.
+  **org_info** - Получение информации о организации.
+  **all_user** - Получение списка пользователей.
+  **create_user(email)** - Создание нового пользователя с полными правами.
+  **restore_password(email)** - Восстановление пароля пользователя.
+  **logout** - Выход из ЛК
+  **all_kkt** - Кассы организаций
+  **api_version** - Версия API
+  **all_retail_places** - Получение списка всех доступных торговых точек
+  **kkm_info(kkm_id)** - Получение данных по ККТ с данным идентификатором
+  **kkm_delete(kkm_id)** - Удаление ККТ с данным идентификатором (не работает)
+  **kkm_transactions(kkm_id, fiscalDriveNumber, \*\*kwargs)** - Получение списка операций по ККТ с данным идентификатором
+  **ticket(transactionId)** - Просмотр чека по определенной транзакции
+  **transaction(transactionId)** - Просмотр чека по определенной транзакции
+  **kkms_count** - Получение количества ККТ
+  **fiscal_kkms** - Получение действующих ККТ (по которым есть хотя бы одна транзакция)
+  **fiscal_drive_numbers(kkmRegId)** - Получение списка фискальных накопителей по определенному регистрационному номеру ККТ
+  **kkms_stats** - Получение общей информации (количество ККТ, ККТ онлайн, количество торговых точек, количество групп ККТ и т.д.) по всем кассам налогоплательщика
+  **process_fiscal_report(report_id)** - Функция обработки отчёта о регистрации (для админки), требует логина в админку.
---
###***grayLog***
`Модуль предназначен для работы с GrayLog`
**Инициализация** grayLog(login , password , host = '10.1.102.24', crpt = False), где crpt - зашифрованый пароль
+  **login** - Авторизация. Запускается автоматически при инициализации объекта, но можно запустить принудительно.
+  **user** - Получение данных о пользователе